/*
 * StringBufferPool.java
 * NetBeans JUnit based test
 *
 * Created on January 21, 2003, 1:02 PM
 */

package com.tagaudit.test;

import junit.framework.Test;
import junit.framework.TestSuite;

import java.lang.StringBuffer;
import com.divnull.util.SBPool;
import junit.framework.TestCase;

/**
 *
 * @author lward
 */
public class StringBufferSpeedTest extends TestCase
{

   public StringBufferSpeedTest(java.lang.String testName)
   {
      super(testName);
   }

   public static void main(java.lang.String[] args)
   {
      junit.textui.TestRunner.run(suite());
   }

   public static Test suite()
   {
      TestSuite suite = new TestSuite(StringBufferSpeedTest.class);
      return suite;
   }

   // Add test methods here, they have to start with 'test' name.
   // for example:
   // public void testHello() {}

   public void testBufferSpeed()
   {
      String part1 = "Now is the time ";
      String part2 = "for all good men ";
      String part3 = "to come to the ";
      String part4 = "aid of my country ";
      String part5 = "'tis of thee, sweet";
      String part6 = "land of libery";

      int v_nRepeat = 10000;
      int v_nIndex = 0;

      /* First, just use strings */
      long start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         String full = part1 + part2 + part3 + part4 + part5 + part6;
         ++v_nIndex;
      }
      long stop = System.currentTimeMillis();
      long duration = stop - start;
      debugLog("String addition test=" + duration + "ms");

      v_nIndex = 0;
      start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         String full = "";
         full = full + part1;
         full = full + part2;
         full = full + part3;
         full = full + part4;
         full = full + part5;
         full = full + part6;
         ++v_nIndex;
      }
      stop = System.currentTimeMillis();
      duration = stop - start;
      debugLog("String naive test=" + duration + "ms");

      v_nIndex = 0;
      start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         String full = "";
         full.concat(part1);
         full.concat(part2);
         full.concat(part3);
         full.concat(part4);
         full.concat(part5);
         full.concat(part6);
         ++v_nIndex;
      }
      stop = System.currentTimeMillis();
      duration = stop - start;
      debugLog("String.concat test=" + duration + "ms");

      /* Now use normal string buffers */
      v_nIndex = 0;
      start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         StringBuffer buffer = new StringBuffer();
         buffer.append(part1);
         buffer.append(part2);
         buffer.append(part3);
         buffer.append(part4);
         buffer.append(part5);
         buffer.append(part6);
         String result = buffer.toString();
         ++v_nIndex;
      }
      stop = System.currentTimeMillis();
      duration = stop - start;
      debugLog("Unsized buffer test=" + duration + "ms");

      /* Now use normal string buffers */
      v_nIndex = 0;
      start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         StringBuffer buffer = new StringBuffer(256);
         buffer.append(part1);
         buffer.append(part2);
         buffer.append(part3);
         buffer.append(part4);
         buffer.append(part5);
         buffer.append(part6);
         String result = buffer.toString();
         ++v_nIndex;
      }
      stop = System.currentTimeMillis();
      duration = stop - start;
      debugLog("Buffer test=" + duration + "ms");

      /* Now use pooled string buffers */
      v_nIndex = 0;
      start = System.currentTimeMillis();
      while (v_nIndex < v_nRepeat)
      {
         StringBuffer buffer = SBPool.borrowBuffer256();
         buffer.append(part1);
         buffer.append(part2);
         buffer.append(part3);
         buffer.append(part4);
         buffer.append(part5);
         buffer.append(part6);
         String result = SBPool.returnBufferGetString(buffer);
         ++v_nIndex;
      }
      stop = System.currentTimeMillis();
      duration = stop - start;
      debugLog("Pooled test=" + duration + "ms");
   }
   
   /** A method to allow tests to dump a message to the standard 
    * output, which can also be changed to do nothing at all.
    * @param message
    */
   protected void debugLog( String message )
   {
      System.out.println(message);
   }
}
